@@ -30,10 +30,20 @@
     'horizon.framework.util.i18n.gettext',
     'horizon.app.core.openstack-service-api.magnum',
     'horizon.app.core.openstack-service-api.nova',
-    'horizon.app.core.openstack-service-api.glance'
+    'horizon.app.core.openstack-service-api.glance',
+    'horizon.dashboard.container-infra.cluster-templates.distros'
   ];
 
-  function ClusterTemplateWorkflow($q, basePath, workflowService, gettext, magnum, nova, glance) {
+  function ClusterTemplateWorkflow(
+    $q,
+    basePath,
+    workflowService,
+    gettext,
+    magnum,
+    nova,
+    glance,
+    distros
+  ) {
     var workflow = {
       init: init,
       update: update
@@ -47,6 +57,7 @@
       var schema;
       var coes = [{value: '', name: gettext("Choose a Container Orchestration Engine")},
                    {value: "swarm", name: gettext("Docker Swarm")},
+                   {value: "swarm-mode", name: gettext("Docker Swarm Mode")},
                    {value: "kubernetes", name: gettext("Kubernetes")},
                    {value: "mesos", name: gettext("Mesos")},
                    {value: "dcos", name: gettext("DC/OS")}];
@@ -54,10 +65,14 @@
       var supportedNetworkDrivers = {
         initial: [{value:"", name: gettext("Choose a Network Driver")},
                   {value: "docker", name: gettext("Docker")},
-                  {value: "flannel", name: gettext("Flannel")}],
-        kubernetes: [{value:"flannel", name: gettext("Flannel")}],
+                  {value: "flannel", name: gettext("Flannel")},
+                  {value: "calico", name: gettext("Calico")}],
+        kubernetes: [{value:"flannel", name: gettext("Flannel")},
+                     {value: "calico", name: gettext("Calico")}],
         swarm: [{value:"docker", name: gettext("Docker")},
                 {value:"flannel", name: gettext("Flannel")}],
+        "swarm-mode": [{value:"docker", name: gettext("Docker")},
+                       {value:"flannel", name: gettext("Flannel")}],
         mesos: [{value:"docker", name: gettext("Docker")}],
         dcos: [{value:"docker", name: gettext("Docker")}]};
       var supportedVolumeDrivers = {
@@ -68,6 +83,8 @@
                      {value:"cinder", name: gettext("Cinder")}],
         swarm: [{value:"", name: gettext("Choose a Volume Driver")},
                 {value:"rexray", name: gettext("Rexray")}],
+        "swarm-mode": [{value:"", name: gettext("Choose a Volume Driver")},
+                       {value:"rexray", name: gettext("Rexray")}],
         mesos: [{value:"", name: gettext("Choose a Volume Driver")},
                 {value:"rexray", name: gettext("Rexray")}],
         dcos: [{value:"", name: gettext("Choose a Volume Driver")},
@@ -93,6 +110,10 @@
             title: gettext('Public'),
             type: 'boolean'
           },
+          'hidden': {
+            title: gettext('Hidden'),
+            type: 'boolean'
+          },
           'registry_enabled': {
             title: gettext('Enable Registry'),
             type: 'boolean'
@@ -252,13 +273,15 @@
                     {
                       key: 'public'
                     },
+                    {
+                      key: 'hidden'
+                    },
                     {
                       key: 'registry_enabled'
                     },
                     {
                       key: 'tls_disabled'
                     }
-
                   ]
                 }
               ],
@@ -314,11 +337,7 @@
                         {
                           key: 'volume_driver',
                           type: 'select',
-                          titleMap: [
-                            {value: '', name: gettext('Choose a Volume Driver')},
-                            {value: 'cinder', name: gettext('Cinder')},
-                            {value: 'rexray', name: gettext('Rexray')}
-                          ]
+                          titleMap: supportedVolumeDrivers.initial
                         }
                       ]
                     },
@@ -331,7 +350,8 @@
                           type: 'select',
                           titleMap: [
                             {value: "devicemapper", name: gettext("Device Mapper")},
-                            {value: "overlay", name: gettext("Overlay")}
+                            {value: "overlay", name: gettext("Overlay")},
+                            {value: "overlay2", name: gettext("Overlay2")}
                           ]
                         }
                       ]
@@ -376,11 +396,7 @@
                         {
                           key: 'network_driver',
                           type: 'select',
-                          titleMap: [
-                            {value: "", name: gettext("Choose a Network Driver")},
-                            {value: "docker", name: gettext("Docker")},
-                            {value: "flannel", name: gettext("Flannel")}
-                          ]
+                          titleMap: supportedNetworkDrivers.initial
                         },
                         {
                           key: 'http_proxy'
@@ -441,9 +457,7 @@
                       htmlClass: 'col-xs-12',
                       items: [
                         {
-                          key: 'labels',
-                          // fixme: to be available, needs to fix bug/1638863
-                          readonly: action === 'update'
+                          key: 'labels'
                         }
                       ]
                     }
@@ -460,13 +474,14 @@
         coe: "",
         server_type: "",
         public: "",
+        hidden: "",
         registry_enabled: "",
         tls_disabled: "",
         image_id: "",
         flavor_id: "",
         master_flavor_id: "",
         docker_volume_size: "",
-        docker_storage_driver: "devicemapper",
+        docker_storage_driver: "",
         keypair_id: "",
         network_driver: "",
         volume_driver: "",
@@ -509,7 +524,10 @@
     function onGetImages(response) {
       images = [{value:"", name: gettext("Choose an Image")}];
       angular.forEach(response.data.items, function(item) {
-        images.push({value: item.name, name: item.name});
+        if (!angular.isUndefined(item.properties) &&
+          distros.indexOf(item.properties.os_distro) >= 0) {
+          images.push({value: item.name, name: item.name});
+        }
       });
       form[0].tabs[1].items[0].items[0].items[0].titleMap = images;
       var deferred = $q.defer();
